@@ -3,23 +3,23 @@ package de.saumya.mojo.gem;
 import java.io.IOException;
 
 import org.apache.maven.plugin.MojoExecutionException;
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.Parameter;
 
 import de.saumya.mojo.ruby.script.ScriptException;
 
 /**
  * goal to run gem with the given arguments.
- * 
- * @goal gem
+ * <br/>
+ * DEPRECATED - DO NOT USE
  */
 @Deprecated
+@Mojo( name = "gem" )
 public class GemMojo extends AbstractGemMojo {
     /**
      * arguments for the gem command of JRuby.
-     * <br/>
-     * Command line -Dgem.args=...
-     * 
-     * @parameter default-value="${gem.args}"
      */
+    @Parameter( property = "gem.args" )
     protected String gemArgs = null;
 
     @Override
